@@ -32,20 +32,24 @@ class Bifrost:
         vialactea_log
     ]
 
-    for dir in PERSIST_DIRECTORIES:
-        if os.path.exists(dir):
-            pass
-        else:
-            os.makedirs(dir)
+    def persist(self):
+        
+        try:
 
-    for link in NAV_DIR_LINKS:
-        with winshell.shortcut(link) as flink:
-            flink.path = link
-            flink.description = link.split('\\')[-1]
+            for persist_dir in self.PERSIST_DIRECTORIES:
+                if os.path.exists(persist_dir):
+                    pass
+                else:
+                    os.makedirs(persist_dir)
 
-    for file in list(os.listdir(vialactea_in_dir)):
-        if '.lnk' in file:
-            shutil.move(f'{vialactea_in_dir}\\{file}', f'{nav_dir}\\{file}')
+            
+            for dest in self.NAV_DIR_LINKS:
+                link_filepath = os.path.join(self.nav_dir, f'{os.path.basename(dest)}.lnk')
+                with winshell.shortcut(link_filepath) as link:
+                    link.path = dest
+        
+        except Exception as e:
+            print('Something went wrong ', e)
 
 
-_bifrost = Bifrost()
+__bifrost: Bifrost = Bifrost()
